from aniparse.output_schemas import VideoResolution, SequenceNumber, SequenceIdentifierNumber, SequenceRange, SeriesInfo, Metadata

episode_titles = [
    Metadata(
        file_name="01 - land of visible pain",
        series=[
            SeriesInfo(
                episode=[
                    SequenceNumber(
                        number=1,
                        title="land of visible pain"
                    )
                ]
            )
        ]
    ),
    Metadata(
        file_name="attack on titan - episode 3 - a dim light amid despair / humanity's comeback, part 1",
        series=[
            SeriesInfo(
                title="attack on titan",
                episode=[
                    SequenceNumber(
                        number=3,
                        title="a dim light amid despair / humanity's comeback, part 1"
                    )
                ]
            )
        ]
    ),
    Metadata(
        file_name="ep. 01 - the boy in the iceberg",
        series=[
            SeriesInfo(
                episode=[
                    SequenceNumber(
                        number=1,
                        title="the boy in the iceberg"
                    )
                ]
            )
        ]
    ),
    Metadata(
        file_name="fate_stay_night_ep05_the_two_magi_part1_[720p,bluray,x264]_-_thora",
        release_group=[
            "thora"
        ],
        series=[
            SeriesInfo(
                title="fate stay night",
                episode=[
                    SequenceNumber(
                        number=5,
                        title="the two magi part 1"
                    )
                ]
            )
        ],
        source=[
            "bluray"
        ],
        video_resolution=[
            VideoResolution(
                video_height=720,
                scan_method="p"
            )
        ],
        video_term=[
            "x264"
        ]
    ),
    Metadata(
        file_name="dramatical murder episode 1 - data_01_login",
        series=[
            SeriesInfo(
                title="dramatical murder",
                episode=[
                    SequenceNumber(
                        number=1,
                        title="data 01 login"
                    )
                ]
            )
        ]
    ),
    Metadata(
        file_name="k-on!!_ep08_career_plan!_[1080p,bluray,x264]_-_thora",
        release_group=[
            "thora"
        ],
        series=[
            SeriesInfo(
                title="k-on!!",
                episode=[
                    SequenceNumber(
                        number=8,
                        title="career plan!"
                    )
                ]
            )
        ],
        video_resolution=[
            VideoResolution(
                video_height=1080,
                scan_method="p"
            )
        ],
        source=[
            "bluray"
        ],
        video_term=[
            "x264"
        ]
    ),
    Metadata(
        file_name="toradora!-03-your-song",
        series=[
            SeriesInfo(
                title="toradora!",
                episode=[
                    SequenceNumber(
                        number=3,
                        title="your song"
                    )
                ]
            )
        ]
    ),
    Metadata(
        file_name="toradora-e03-your-song",
        series=[
            SeriesInfo(
                title="toradora",
                episode=[
                    SequenceNumber(
                        number=3,
                        title="your song"
                    )
                ]
            )
        ]
    ),
    Metadata(
        file_name="tsuredure children episódio 1 – confession",
        series=[
            SeriesInfo(
                title="tsuredure children",
                episode=[
                    SequenceNumber(
                        number=1,
                        title="confession"
                    )
                ]
            )
        ]
    ),
    Metadata(
        file_name="[5f] rwby - 14 forever fall part 2 pt-br",
        language=[
            "pt-br"
        ],
        release_group=[
            "5f"
        ],
        series=[
            SeriesInfo(
                title="rwby",
                episode=[
                    SequenceNumber(
                        number=14,
                        title="forever fall part 2"
                    )
                ]
            )
        ]
    ),
    Metadata(
        file_checksum="cbdb8577",
        file_name="[acx]neon_genesis_evangelion_-_platinum_-_06_-_showdown_in_tokyo_3_[saintdeath]_[cbdb8577]",
        release_group=[
            "acx"
        ],
        series=[
            SeriesInfo(
                title="neon genesis evangelion - platinum",
                episode=[
                    SequenceNumber(
                        number=6,
                        title="showdown in tokyo 3"
                    )
                ]
            )
        ],
        unknown=[
            "saintdeath"
        ]
    ),
    Metadata(
        audio_term=[
            "ac3"
        ],
        file_checksum="650b731b",
        file_name="[ayu]_kiddy_grade_2_-_pilot_[h264_ac3][650b731b]",
        release_group=[
            "ayu"
        ],
        series=[
            SeriesInfo(
                title="kiddy grade 2"
            )
        ],
        video_term=[
            "h264"
        ]
    ),
    Metadata(
        file_checksum="8f59f2ba",
        file_name="[bm&t] toradora! - 07v2 - pool opening [720p hi10 ] [bd] [8f59f2ba]",
        release_group=[
            "bm&t"
        ],
        series=[
            SeriesInfo(
                title="toradora!",
                episode=[
                    SequenceNumber(
                        number=7,
                        release_version="2",
                        title="pool opening"
                    )
                ]
            )
        ],
        video_resolution=[
            VideoResolution(
                video_height=720,
                scan_method="p"
            )
        ],
        source=[
            "bd"
        ],
        video_term=[
            "hi10"
        ]
    ),
    Metadata(
        file_name="[judas] initial d - extra stage 02 - sentimental white",
        release_group=[
            "judas"
        ],
        series=[
            SeriesInfo(
                title="initial d - extra stage",
                episode=[
                    SequenceNumber(
                        number=2,
                        title="sentimental white"
                    )
                ]
            )
        ]
    ),
    Metadata(
        audio_term=[
            "aac"
        ],
        file_checksum="4a9ab85f",
        file_name="[ninjapanda] tiger & bunny #01 all's well that ends well. (v3, 1080p hi10p, da aac) [4a9ab85f]",
        release_group=[
            "ninjapanda"
        ],
        release_version=[
            "3"
        ],
        series=[
            SeriesInfo(
                title="tiger & bunny",
                episode=[
                    SequenceNumber(
                        number=1,
                        title="all's well that ends well."
                    )
                ]
            )
        ],
        video_resolution=[
            VideoResolution(
                video_height=1080,
                scan_method="p"
            )
        ],
        video_term=[
            "hi10p"
        ],
        unknown=[
            "da"
        ]
    ),
    Metadata(
        audio_term=[
            "dual audio",
            "flac"
        ],
        file_checksum="8a45634b",
        file_name="[raizel] persona 4 the animation episode 13 - a stormy summer vacation part 1  [bd_1080p_dual_audio_flac_hi10p][8a45634b]",
        release_group=[
            "raizel"
        ],
        series=[
            SeriesInfo(
                title="persona 4 the animation",
                episode=[
                    SequenceNumber(
                        number=13,
                        title="a stormy summer vacation part 1"
                    )
                ]
            )
        ],
        video_resolution=[
            VideoResolution(
                video_height=1080,
                scan_method="p"
            )
        ],
        video_term=[
            "hi10p"
        ]
    ),
    Metadata(
        audio_term=[
            "flac"
        ],
        file_checksum="1234abcd",
        file_name="[taigasubs]_toradora!_(2008)_-_01v2_-_tiger_and_dragon_[1280x720_h.264_flac][1234abcd]",
        release_group=[
            "taigasubs"
        ],
        series=[
            SeriesInfo(
                title="toradora!",
                year=[
                    SequenceNumber(
                        number=2008
                    )
                ],
                episode=[
                    SequenceNumber(
                        number=1,
                        release_version="2",
                        title="tiger and dragon"
                    )
                ]
            )
        ],
        video_resolution=[
            VideoResolution(
                video_height=720,
                video_width=1280
            )
        ],
        video_term=[
            "h.264"
        ]
    ),
    Metadata(
        file_checksum="b99c8ded",
        file_name="[zom-b] machine-doll wa kizutsukanai - 01 - facing ''cannibal candy'' i (kuroi, fff remux) [b99c8ded]",
        release_group=[
            "zom-b"
        ],
        release_information=[
            "remux"
        ],
        series=[
            SeriesInfo(
                title="machine-doll wa kizutsukanai",
                episode=[
                    SequenceNumber(
                        number=1,
                        title="facing 'cannibal candy' i"
                    )
                ]
            )
        ],
        unknown=[
            "kuroi",
            "fff"
        ]
    ),
    Metadata(
        audio_term=[
            "aac"
        ],
        file_checksum="f7df16f7",
        file_name="[zurako] sora no woto - 07.5 - drinking party - fortress battle (bd 1080p aac) [f7df16f7]",
        release_group=[
            "zurako"
        ],
        series=[
            SeriesInfo(
                title="sora no woto",
                episode=[
                    SequenceNumber(
                        number=7.5,
                        title="drinking party - fortress battle"
                    )
                ]
            )
        ],
        source=[
            "bd"
        ],
        video_resolution=[
            VideoResolution(
                video_height=1080,
                scan_method="p"
            )
        ]
    ),
    Metadata(
        file_name="[chibi-doki] seikon no qwaser - 13v0 (uncensored director's cut) [988db090]",
        file_checksum="988db090",
        release_group=[
            "chibi-doki"
        ],
        series=[
            SeriesInfo(
                title="seikon no qwaser",
                episode=[
                    SequenceNumber(
                        number=13,
                        release_version="0",
                        title="uncensored director's cut"
                    )
                ]
            )
        ]
    ),
    Metadata(
        file_name="The Eminence in Shadow vol 2 06 Pretenders",
        series=[
            SeriesInfo(
                title="The Eminence in Shadow",
                episode=[
                    SequenceNumber(
                        number=6,
                        title="Pretenders"
                    )
                ],
                volume=[
                    SequenceNumber(
                        number=2
                    )
                ]
            )
        ]
    )
]
